![Image of PyGit Logo](https://github.com/malgulam/PyGit/blob/master/pygit/PyGitLogo.png) 
# py_git
## Python Git-like VC Tool For Pythonic Git Actions.
### Essentially: Pythonically Git
 -  PyGit is a python package / module that helps developers get the best out of Git, quickly and effeciently. 
 
 - With its simple function calls such as:
```bash
bash terminal 
---------------------------------------------------------------------------------------------------
$ pip3 install py_git
$ python3 -m py_git.pygit --automate_actions push
$ python3 -m py_git.pygit --automate_actions push
```
 - The above bash code helps the developer effortlessly push new code / builds to Github with little to no further
 input.
 - The automate_actions has a parameter known as commit_msg set to 'new changes' at default.
 - Essentially at its core , PyGit is a pythonic lesser to git, seeing as to how its entire
 functionality depends on git software.
## Requirements:
 - Initialise of SSH keys in os.path['PATH'] to enable quick push, pull, fetch, merge, etc.Make sure you have gone through the creation and deployment of SSH keys to github account to enable the program run without needing to always cache credentials.
 - Python3.6+
 - Directory name of realpath of current working file as shown in the code samples one line 15 and 16.
 - Linux based operating system.This is as a result of the default file handling operations carried out.This can be modified to run on Windows OS.
 - At least 2GB of RAM.
 - At least 32 GB of storage.
 - Contribute!

## Documentation:
- Todo
*Check out pypi @druzgeorge @agulam-coco*



**Much contribution will be needed.Thanks in advance. :]**
